@@ -23,27 +23,22 @@
 #  Based on code from libpodcasts.py (thp, 2005-10-29)
 #
 
+import cgi
+import logging
+import os
+import re
+import time
+
+from gi.repository import GdkPixbuf, GObject, Gtk
+
 import gpodder
+from gpodder import coverart, model, query, util
+from gpodder.gtkui import draw
 
 _ = gpodder.gettext
 
-from gpodder import util
-from gpodder import model
-from gpodder import query
-from gpodder import coverart
-
-import logging
 logger = logging.getLogger(__name__)
 
-from gpodder.gtkui import draw
-
-import os
-from gi.repository import Gtk
-from gi.repository import GObject
-from gi.repository import GdkPixbuf
-import cgi
-import re
-import time
 
 try:
     from gi.repository import Gio
@@ -166,9 +161,10 @@ class EpisodeListModel(Gtk.ListStore):
     PROGRESS_STEPS = 20
 
     def __init__(self, config, on_filter_changed=lambda has_episodes: None):
-        Gtk.ListStore.__init__(self, str, str, str, object,
-                str, str, str, str, bool, bool, bool,
-                GObject.TYPE_INT64, GObject.TYPE_INT64, str, bool, GObject.TYPE_INT64, bool)
+        Gtk.ListStore.__init__(self, str, str, str, object, str, str, str,
+                               str, bool, bool, bool, GObject.TYPE_INT64,
+                               GObject.TYPE_INT64, str, bool,
+                               GObject.TYPE_INT64, bool)
 
         self._config = config
 
@@ -853,7 +849,8 @@ class PodcastListModel(Gtk.ListStore):
             description = '<span size="16000"> </span><b>%s</b>' % (
                     cgi.escape(section))
 
-            self.set(iter,
+            self.set(
+                iter,
                 self.C_DESCRIPTION, description,
                 self.C_SECTION, section,
                 self.C_VIEW_SHOW_UNDELETED, total - deleted > 0,
